@@ -18,11 +18,38 @@ from google.cloud.gke_multicloud import gapic_version as package_version
 __version__ = package_version.__version__
 
 
+from .services.attached_clusters import (
+    AttachedClustersAsyncClient,
+    AttachedClustersClient,
+)
 from .services.aws_clusters import AwsClustersAsyncClient, AwsClustersClient
 from .services.azure_clusters import AzureClustersAsyncClient, AzureClustersClient
+from .types.attached_resources import (
+    AttachedCluster,
+    AttachedClusterError,
+    AttachedClustersAuthorization,
+    AttachedClusterUser,
+    AttachedOidcConfig,
+    AttachedPlatformVersionInfo,
+    AttachedServerConfig,
+)
+from .types.attached_service import (
+    CreateAttachedClusterRequest,
+    DeleteAttachedClusterRequest,
+    GenerateAttachedClusterInstallManifestRequest,
+    GenerateAttachedClusterInstallManifestResponse,
+    GetAttachedClusterRequest,
+    GetAttachedServerConfigRequest,
+    ImportAttachedClusterRequest,
+    ListAttachedClustersRequest,
+    ListAttachedClustersResponse,
+    UpdateAttachedClusterRequest,
+)
 from .types.aws_resources import (
     AwsAuthorization,
+    AwsAutoscalingGroupMetricsCollection,
     AwsCluster,
+    AwsClusterError,
     AwsClusterNetworking,
     AwsClusterUser,
     AwsConfigEncryption,
@@ -33,6 +60,7 @@ from .types.aws_resources import (
     AwsNodeConfig,
     AwsNodePool,
     AwsNodePoolAutoscaling,
+    AwsNodePoolError,
     AwsProxyConfig,
     AwsServerConfig,
     AwsServicesAuthentication,
@@ -60,6 +88,7 @@ from .types.azure_resources import (
     AzureAuthorization,
     AzureClient,
     AzureCluster,
+    AzureClusterError,
     AzureClusterNetworking,
     AzureClusterResources,
     AzureClusterUser,
@@ -71,6 +100,7 @@ from .types.azure_resources import (
     AzureNodeConfig,
     AzureNodePool,
     AzureNodePoolAutoscaling,
+    AzureNodePoolError,
     AzureProxyConfig,
     AzureServerConfig,
     AzureSshConfig,
@@ -102,17 +132,30 @@ from .types.common_resources import (
     Fleet,
     LoggingComponentConfig,
     LoggingConfig,
+    ManagedPrometheusConfig,
     MaxPodsConstraint,
+    MonitoringConfig,
     NodeTaint,
     OperationMetadata,
     WorkloadIdentityConfig,
 )
 
 __all__ = (
+    "AttachedClustersAsyncClient",
     "AwsClustersAsyncClient",
     "AzureClustersAsyncClient",
+    "AttachedCluster",
+    "AttachedClusterError",
+    "AttachedClusterUser",
+    "AttachedClustersAuthorization",
+    "AttachedClustersClient",
+    "AttachedOidcConfig",
+    "AttachedPlatformVersionInfo",
+    "AttachedServerConfig",
     "AwsAuthorization",
+    "AwsAutoscalingGroupMetricsCollection",
     "AwsCluster",
+    "AwsClusterError",
     "AwsClusterNetworking",
     "AwsClusterUser",
     "AwsClustersClient",
@@ -124,6 +167,7 @@ __all__ = (
     "AwsNodeConfig",
     "AwsNodePool",
     "AwsNodePoolAutoscaling",
+    "AwsNodePoolError",
     "AwsProxyConfig",
     "AwsServerConfig",
     "AwsServicesAuthentication",
@@ -132,6 +176,7 @@ __all__ = (
     "AzureAuthorization",
     "AzureClient",
     "AzureCluster",
+    "AzureClusterError",
     "AzureClusterNetworking",
     "AzureClusterResources",
     "AzureClusterUser",
@@ -144,24 +189,31 @@ __all__ = (
     "AzureNodeConfig",
     "AzureNodePool",
     "AzureNodePoolAutoscaling",
+    "AzureNodePoolError",
     "AzureProxyConfig",
     "AzureServerConfig",
     "AzureSshConfig",
+    "CreateAttachedClusterRequest",
     "CreateAwsClusterRequest",
     "CreateAwsNodePoolRequest",
     "CreateAzureClientRequest",
     "CreateAzureClusterRequest",
     "CreateAzureNodePoolRequest",
+    "DeleteAttachedClusterRequest",
     "DeleteAwsClusterRequest",
     "DeleteAwsNodePoolRequest",
     "DeleteAzureClientRequest",
     "DeleteAzureClusterRequest",
     "DeleteAzureNodePoolRequest",
     "Fleet",
+    "GenerateAttachedClusterInstallManifestRequest",
+    "GenerateAttachedClusterInstallManifestResponse",
     "GenerateAwsAccessTokenRequest",
     "GenerateAwsAccessTokenResponse",
     "GenerateAzureAccessTokenRequest",
     "GenerateAzureAccessTokenResponse",
+    "GetAttachedClusterRequest",
+    "GetAttachedServerConfigRequest",
     "GetAwsClusterRequest",
     "GetAwsNodePoolRequest",
     "GetAwsServerConfigRequest",
@@ -169,6 +221,9 @@ __all__ = (
     "GetAzureClusterRequest",
     "GetAzureNodePoolRequest",
     "GetAzureServerConfigRequest",
+    "ImportAttachedClusterRequest",
+    "ListAttachedClustersRequest",
+    "ListAttachedClustersResponse",
     "ListAwsClustersRequest",
     "ListAwsClustersResponse",
     "ListAwsNodePoolsRequest",
@@ -181,10 +236,13 @@ __all__ = (
     "ListAzureNodePoolsResponse",
     "LoggingComponentConfig",
     "LoggingConfig",
+    "ManagedPrometheusConfig",
     "MaxPodsConstraint",
+    "MonitoringConfig",
     "NodeTaint",
     "OperationMetadata",
     "ReplicaPlacement",
+    "UpdateAttachedClusterRequest",
     "UpdateAwsClusterRequest",
     "UpdateAwsNodePoolRequest",
     "UpdateAzureClusterRequest",
