@@ -48,6 +48,7 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
+from google.longrunning import operations_pb2
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
@@ -349,7 +350,7 @@ class AwsClustersClient(metaclass=AwsClustersClientMeta):
         The API endpoint is determined in the following order:
         (1) if `client_options.api_endpoint` if provided, use the provided one.
         (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
-        default mTLS endpoint; if the environment variabel is "never", use the default API
+        default mTLS endpoint; if the environment variable is "never", use the default API
         endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
         use the default API endpoint.
 
@@ -550,6 +551,7 @@ class AwsClustersClient(metaclass=AwsClustersClientMeta):
                 aws_cluster.control_plane.aws_services_authentication.role_arn = "role_arn_value"
                 aws_cluster.control_plane.config_encryption.kms_key_arn = "kms_key_arn_value"
                 aws_cluster.authorization.admin_users.username = "username_value"
+                aws_cluster.fleet.project = "project_value"
 
                 request = gke_multicloud_v1.CreateAwsClusterRequest(
                     parent="parent_value",
@@ -604,7 +606,7 @@ class AwsClustersClient(metaclass=AwsClustersClientMeta):
                 ``projects/<project-id>/locations/<region>/awsClusters/<cluster-id>``.
 
                 Valid characters are ``/[a-z][0-9]-/``. Cannot be longer
-                than 40 characters.
+                than 63 characters.
 
                 This corresponds to the ``aws_cluster_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -719,6 +721,7 @@ class AwsClustersClient(metaclass=AwsClustersClientMeta):
                 aws_cluster.control_plane.aws_services_authentication.role_arn = "role_arn_value"
                 aws_cluster.control_plane.config_encryption.kms_key_arn = "kms_key_arn_value"
                 aws_cluster.authorization.admin_users.username = "username_value"
+                aws_cluster.fleet.project = "project_value"
 
                 request = gke_multicloud_v1.UpdateAwsClusterRequest(
                     aws_cluster=aws_cluster,
@@ -764,14 +767,17 @@ class AwsClustersClient(metaclass=AwsClustersClientMeta):
                 -  ``control_plane.proxy_config``.
                 -  ``control_plane.proxy_config.secret_arn``.
                 -  ``control_plane.proxy_config.secret_version``.
+                -  ``control_plane.root_volume.size_gib``.
+                -  ``control_plane.root_volume.volume_type``.
                 -  ``control_plane.root_volume.iops``.
                 -  ``control_plane.root_volume.kms_key_arn``.
-                -  ``control_plane.root_volume.volume_type``.
-                -  ``control_plane.root_volume.size_gib``.
                 -  ``control_plane.ssh_config``.
                 -  ``control_plane.ssh_config.ec2_key_pair``.
                 -  ``control_plane.instance_placement.tenancy``.
-                -  ``logging_config``.
+                -  ``control_plane.iam_instance_profile``.
+                -  ``logging_config.component_config.enable_components``.
+                -  ``control_plane.tags``.
+                -  ``monitoring_config.managed_prometheus_config.enabled``.
 
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1405,7 +1411,7 @@ class AwsClustersClient(metaclass=AwsClustersClientMeta):
                 ``projects/<project-id>/locations/<region>/awsClusters/<cluster-id>/awsNodePools/<node-pool-id>``.
 
                 Valid characters are ``/[a-z][0-9]-/``. Cannot be longer
-                than 40 characters.
+                than 63 characters.
 
                 This corresponds to the ``aws_node_pool_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1564,6 +1570,13 @@ class AwsClustersClient(metaclass=AwsClustersClientMeta):
                 -  ``config.proxy_config.secret_version``.
                 -  ``config.ssh_config``.
                 -  ``config.ssh_config.ec2_key_pair``.
+                -  ``config.instance_placement.tenancy``.
+                -  ``config.iam_instance_profile``.
+                -  ``config.labels``.
+                -  ``config.tags``.
+                -  ``config.autoscaling_metrics_collection``.
+                -  ``config.autoscaling_metrics_collection.granularity``.
+                -  ``config.autoscaling_metrics_collection.metrics``.
 
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -1924,7 +1937,7 @@ class AwsClustersClient(metaclass=AwsClustersClientMeta):
         Args:
             request (Union[google.cloud.gke_multicloud_v1.types.DeleteAwsNodePoolRequest, dict]):
                 The request object. Request message for
-                `AwsClusters.DeleteNodePool` method.
+                `AwsClusters.DeleteAwsNodePool` method.
             name (str):
                 Required. The resource name the
                 [AwsNodePool][google.cloud.gkemulticloud.v1.AwsNodePool]
@@ -2137,6 +2150,223 @@ class AwsClustersClient(metaclass=AwsClustersClientMeta):
         """
         self.transport.close()
 
+    def list_operations(
+        self,
+        request: Optional[operations_pb2.ListOperationsRequest] = None,
+        *,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> operations_pb2.ListOperationsResponse:
+        r"""Lists operations that match the specified filter in the request.
+
+        Args:
+            request (:class:`~.operations_pb2.ListOperationsRequest`):
+                The request object. Request message for
+                `ListOperations` method.
+            retry (google.api_core.retry.Retry): Designation of what errors,
+                    if any, should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+        Returns:
+            ~.operations_pb2.ListOperationsResponse:
+                Response message for ``ListOperations`` method.
+        """
+        # Create or coerce a protobuf request object.
+        # The request isn't a proto-plus wrapped type,
+        # so it must be constructed via keyword expansion.
+        if isinstance(request, dict):
+            request = operations_pb2.ListOperationsRequest(**request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method.wrap_method(
+            self._transport.list_operations,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
+    def get_operation(
+        self,
+        request: Optional[operations_pb2.GetOperationRequest] = None,
+        *,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> operations_pb2.Operation:
+        r"""Gets the latest state of a long-running operation.
+
+        Args:
+            request (:class:`~.operations_pb2.GetOperationRequest`):
+                The request object. Request message for
+                `GetOperation` method.
+            retry (google.api_core.retry.Retry): Designation of what errors,
+                    if any, should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+        Returns:
+            ~.operations_pb2.Operation:
+                An ``Operation`` object.
+        """
+        # Create or coerce a protobuf request object.
+        # The request isn't a proto-plus wrapped type,
+        # so it must be constructed via keyword expansion.
+        if isinstance(request, dict):
+            request = operations_pb2.GetOperationRequest(**request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method.wrap_method(
+            self._transport.get_operation,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+        # Done; return the response.
+        return response
+
+    def delete_operation(
+        self,
+        request: Optional[operations_pb2.DeleteOperationRequest] = None,
+        *,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> None:
+        r"""Deletes a long-running operation.
+
+        This method indicates that the client is no longer interested
+        in the operation result. It does not cancel the operation.
+        If the server doesn't support this method, it returns
+        `google.rpc.Code.UNIMPLEMENTED`.
+
+        Args:
+            request (:class:`~.operations_pb2.DeleteOperationRequest`):
+                The request object. Request message for
+                `DeleteOperation` method.
+            retry (google.api_core.retry.Retry): Designation of what errors,
+                    if any, should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+        Returns:
+            None
+        """
+        # Create or coerce a protobuf request object.
+        # The request isn't a proto-plus wrapped type,
+        # so it must be constructed via keyword expansion.
+        if isinstance(request, dict):
+            request = operations_pb2.DeleteOperationRequest(**request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method.wrap_method(
+            self._transport.delete_operation,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
+    def cancel_operation(
+        self,
+        request: Optional[operations_pb2.CancelOperationRequest] = None,
+        *,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
+        metadata: Sequence[Tuple[str, str]] = (),
+    ) -> None:
+        r"""Starts asynchronous cancellation on a long-running operation.
+
+        The server makes a best effort to cancel the operation, but success
+        is not guaranteed.  If the server doesn't support this method, it returns
+        `google.rpc.Code.UNIMPLEMENTED`.
+
+        Args:
+            request (:class:`~.operations_pb2.CancelOperationRequest`):
+                The request object. Request message for
+                `CancelOperation` method.
+            retry (google.api_core.retry.Retry): Designation of what errors,
+                    if any, should be retried.
+            timeout (float): The timeout for this request.
+            metadata (Sequence[Tuple[str, str]]): Strings which should be
+                sent along with the request as metadata.
+        Returns:
+            None
+        """
+        # Create or coerce a protobuf request object.
+        # The request isn't a proto-plus wrapped type,
+        # so it must be constructed via keyword expansion.
+        if isinstance(request, dict):
+            request = operations_pb2.CancelOperationRequest(**request)
+
+        # Wrap the RPC method; this adds retry and timeout information,
+        # and friendly error handling.
+        rpc = gapic_v1.method.wrap_method(
+            self._transport.cancel_operation,
+            default_timeout=None,
+            client_info=DEFAULT_CLIENT_INFO,
+        )
+
+        # Certain fields should be provided within the metadata header;
+        # add these here.
+        metadata = tuple(metadata) + (
+            gapic_v1.routing_header.to_grpc_metadata((("name", request.name),)),
+        )
+
+        # Send the request.
+        rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
+
 
 DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
     gapic_version=package_version.__version__
